@@ -1,7 +1,7 @@
 package Data::Dmp;
 
-our $DATE = '2015-03-24'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $DATE = '2015-04-26'; # DATE
+our $VERSION = '0.11'; # VERSION
 
 use 5.010001;
 use strict;
@@ -143,7 +143,7 @@ sub _dd_or_dmp {
     }
 }
 
-sub dd { local $_is_dd=1; _dd_or_dmp(@_) }
+sub dd { local $_is_dd=1; _dd_or_dmp(@_) } # goto &sub doesn't work here
 sub dmp { goto &_dd_or_dmp }
 
 1;
@@ -161,7 +161,7 @@ Data::Dmp - Dump Perl data structures as Perl code
 
 =head1 VERSION
 
-This document describes version 0.10 of Data::Dmp (from Perl distribution Data-Dmp), released on 2015-03-24.
+This document describes version 0.11 of Data::Dmp (from Perl distribution Data-Dmp), released on 2015-04-26.
 
 =head1 SYNOPSIS
 
@@ -174,9 +174,10 @@ This document describes version 0.10 of Data::Dmp (from Perl distribution Data-D
 Data::Dmp is a Perl dumper like L<Data::Dumper>. It's compact (only about 120
 lines of code long), starts fast and does not use other module except
 L<Regexp::Stringify> when dumping regexes. It produces compact output (similar
-to L<Data::Dumper::Concise>. It's faster than Data::Dumper, but does not offer
-the various formatting options. It supports dumping objects, regexes, circular
-objects. Its code is based on L<Data::Dump>.
+to L<Data::Dumper::Concise>). It roughly has the same speed as Data::Dumper
+(usually a bit faster for smaller structures), but does not offer the various
+formatting options. It supports dumping objects, regexes, circular structures.
+Its code is based on L<Data::Dump>.
 
 It currently does not support "deparse" like Data::Dumper and dumps coderefs as
 C<< sub{'DUMMY'} >>. Unlike Data::Dump, it currently does not support
@@ -204,6 +205,26 @@ Set target Perl version. Currently this is used when passing to
 L<Regexp::Stringify>. If you set this to, say C<5.010>, then the dumped code
 will keep compatibility with Perl 5.10.0.
 
+=head1 BENCHMARKS
+
+ [1..10]:
+                      Rate    Data::Dump Data::Dumper Data::Dmp
+ Data::Dump    27755+-31/s            --       -67.8%    -80.8%
+ Data::Dumper  86104+-99/s  210.23+-0.5%           --    -40.4%
+ Data::Dmp    144429+-62/s 420.38+-0.63% 67.74+-0.21%        --
+ 
+ [1..100]:
+                     Rate  Data::Dump Data::Dumper Data::Dmp
+ Data::Dump    3487+-14/s          --       -77.0%    -81.5%
+ Data::Dumper 15129+-23/s 333.8+-1.8%           --    -19.7%
+ Data::Dmp    18835+-33/s 440.1+-2.3% 24.49+-0.29%        --
+ 
+ Some mixed structure:
+                     Rate   Data::Dump    Data::Dmp Data::Dumper
+ Data::Dump    8455+-15/s           --       -72.7%       -80.7%
+ Data::Dmp    31023+-53/s 266.9+-0.91%           --       -29.0%
+ Data::Dumper 43717+-51/s    417+-1.1% 40.92+-0.29%           --
+
 =head1 FAQ
 
 =head2 When to use Data::Dmp? How does it compare to other dumper modules?
